//
//  Color.swift
//  DouShouQiIOS
//
//  Created by Pierre FERREIRA on 31/05/2024.
//

import Foundation
import SwiftUI

public extension Color {
    init(hex: String) {
        let hex = hex.trimmingCharacters(in: CharacterSet.alphanumerics.inverted)
        var int: UInt64 = 0
        Scanner(string: hex).scanHexInt64(&int)
        let a, r, g, b: UInt64
        switch hex.count {
        case 3: // RGB (12-bit)
            (a, r, g, b) = (255, (int >> 8) * 17, (int >> 4 & 0xF) * 17, (int & 0xF) * 17)
        case 6: // RGB (24-bit)
            (a, r, g, b) = (255, int >> 16, int >> 8 & 0xFF, int & 0xFF)
        case 8: // ARGB (32-bit)
            (a, r, g, b) = (int >> 24, int >> 16 & 0xFF, int >> 8 & 0xFF, int & 0xFF)
        default:
            (a, r, g, b) = (1, 1, 1, 0)
        }

        self.init(
            .sRGB,
            red: Double(r) / 255,
            green: Double(g) / 255,
            blue:  Double(b) / 255,
            opacity: Double(a) / 255
        )
    }

    
    static let primaryColor : Color = Color("ColorPrimary")
    static let secondaryColor : Color = Color.orange.opacity(0.3)
    static let tertiaryColor : Color = Color.orange
    static let QuadiaryColor : Color = Color.yellow
    
    static let player1 : Color = Color("ColorP1")
    static let player2 : Color = Color("ColorP2")

    static let bgColor : Color = Color("ColorBG")
    static let fontColor : Color = Color("ColorFont")

    
    /*
    ///Light
    static let primaryColor : Color = Color.yellow
    static let secondaryColor : Color = Color.orange.opacity(0.3)
    static let tertiaryColor : Color = Color.orange
    static let QuadiaryColor : Color = Color.yellow
    
    static let player1 : Color = Color.yellow
    static let player2 : Color = Color.red

    static let bgColor : Color = Color.white
    static let fontColor : Color = Color(hex: "222831")

    
    ///Dark
    static let primaryColorDark : Color = Color(hex: "393E46")
    static let secondaryColorDark : Color = Color.gray.opacity(0.3)
    static let tertiaryColorDark : Color = Color.gray
    static let QuadiaryColorDark : Color = Color.yellow
    
    static let player1Dark : Color = Color.yellow.opacity(5)
    static let player2Dark : Color = Color.red
    
    static let bgColorDark : Color = Color(hex: "222831")
    static let fontColorDark : Color = Color(hex: "EEEEEE")
    
    */
}
